package com.muyu.etl.server.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.muyu.common.core.domain.Result;
import com.muyu.etl.common.domain.DataSources;
import com.muyu.etl.common.domain.req.DataSourcesReq;
import com.muyu.etl.common.domain.resp.DataSourcesRes;
import com.muyu.etl.server.service.DataSourcesService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.PageRequest;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Author：zhangzhihao
 * @name：DataSourcesController
 * @Date：2024/8/21 14:47
 * 不准抄代码，添加注释，清楚每一行代码意思
 */
@RestController
@RequestMapping("etl")
public class DataSourcesController {

    @Autowired
    private DataSourcesService dataSourcesService;

    /**
     * 通过ID查询单条数据
     * @param  id 主键
     * @return 实例对象
     */
    @GetMapping("/{id}")
    public Result<DataSources> queryById(@PathVariable("id") Integer id){
        return Result.success(dataSourcesService.getById(id));
    }

    /**
     * 查询所有已有数据源
     * @param req
     * @return
     */
    @PostMapping("/all")
    public Result<Page<DataSources>> all(@RequestBody DataSourcesReq req){

        return Result.success(dataSourcesService.selectList(req));
    }


    /**
     * 新增数据来源
     * @param dataSources 实例对象
     * @return 实例对象
     */
    @PostMapping
    public Result<DataSources> add(@RequestBody DataSources dataSources){
        dataSourcesService.save(dataSources);
        return Result.success();
    }

    /**
     * 更新数据
     *
     * @param dataSources 实例对象
     * @return 实例对象
     */
    @PutMapping
    public Result<DataSources> edit(DataSources dataSources){
        dataSourcesService.update(dataSources);
        return Result.success();
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @DeleteMapping("/{id}")
    public Result<Boolean> deleteById(@PathVariable("id") Integer id){
        return Result.success(dataSourcesService.removeById(id));
    }
}
